/*******************************************************************************
*
*	Read an HTML input form and produce a directory listing by using a Web Macro.
*
*	Demonstrates:
*
*		1. Using Rexx to process an HTML form.
*		2. Outputting an HTML page that contains Web Macros.
*
*	It can be invoked via a form within the PowerWeb tour. For example:
*
*		<form action=/example/rexx-bin/dirlist.cmd>
*
*	It can also be called standalone. For example:
*
*		<a href=/example/rexx-bin/dirlist.cmd?filespec=/p*&showsize=1>Show Root</a>
*
* COPYRIGHT:
*   CompuSource (Pty) Ltd
*   Licensed Materials - Property of CompuSource (Pty) Ltd
*   (C) Copyright CompuSource (Pty) Ltd 1994-1996.
*   All Rights Reserved
*   Use, duplication, or disclosure restricted by international
*   copyright law.
*
*******************************************************************************/

parse arg parcel

/* Tell PowerWeb we will be returning HTML including Web Macros. */
/* If you aren't using Web Macros you can remove this line. */
call ServerWriteText parcel, "Request:/Header/Out/Content-Type", "text/x-server-parsed-html"

/* Read the form input fields - note that PowerWeb has already decoded them. */
fileSpec = ServerReadText(parcel, "Request:/Argument/filespec")
showDate = ServerReadText(parcel, "Request:/Argument/showdate")
showSize = ServerReadText(parcel, "Request:/Argument/showsize")
showDirs = ServerReadText(parcel, "Request:/Argument/showdirs")

/* Handle missing or empty fields by using suitable defaults */
if fileSpec = '' then fileSpec = "/*"
if showDate = '' then showDate = 0
if showSize = '' then showSize = 0
if showDirs = '' then showDirs = 0

/* Output a page title */
html = ServerFind(parcel,"Request:/Result")
call ServerWriteText html,, "<h1>Directory Listing for Documents in "filespec"</h1>"

/* Output a #Dir Web Macro according to the form's fields */
call ServerAppendText html,, "<!--#dir Virtual="filespec

if showDirs then
	call ServerAppendText html,, " IncludeDirectories=yes"

if showDate then
	call ServerAppendText html,, " SuppressLastModified=no"
else
	call ServerAppendText html,, " SuppressLastModified=yes"

if showSize then
	call ServerAppendText html,, " SuppressSize=no"
else
	call ServerAppendText html,, " SuppressSize=yes"

call ServerAppendText html,, "-->"

