/*******************************************************************************
*
* This module presents example PowerWeb Server++ API Hook Functions.
*
* Recursively dump a multi-level list representation of the entire
* tree of Variables, or of a sub-tree if there is an argument to the URL.
*
* Example: "http://127.0.0.1/example/rexx-bin/tree.cmd?Request:/"
*
* It is functionally identical to the C language function
* "TourTree" found in the "tour.cpp" file, but owing to the interpretive
* nature of Rexx, is substantially slower executing.
*
* COPYRIGHT:
*   CompuSource (Pty) Ltd
*   Licensed Materials - Property of CompuSource (Pty) Ltd
*   (C) Copyright CompuSource (Pty) Ltd 1994-1996.
*   All Rights Reserved
*   Use, duplication, or disclosure restricted by international
*   copyright law.
*
*******************************************************************************/

Parse Arg parcel

/*	Get a handle to the HTML result output variable. */

html = ServerFind(parcel, "Request:/Result")

/* Read the argument to the URL (if any) */

buffer = ServerReadText(parcel, "Request:/ArgumentText")

/* If no argument given, use a default of the current Request object. */

if length(buffer) = 0 then
	buffer = "Request:/"

call ServerAppendText html,, "<html><body background=/icons/textures/paper.jpg>"

/* Discover the "root" of the tree to display */

root = ServerFind(parcel, buffer)

if root = 0 then
	call ServerAppendText html,, "Failed to Find the Requested Variable Directory:" buffer
else do
	/* Output a heading. */
	call ServerAppendText html,, "<h2>Tree of Variables Under: "buffer"</h2>"

	/* Call the recursive function to display the tree in HTML */
	call TourTreeRecursion root, html, 0
end

call ServerAppendText html,, "</body></html>"

return "0"

/* ------------------------------------------------------------------- */
/* Recursive subroutine called by the main program. */

TourTreeRecursion: procedure

parse arg root, html, level

/* The type id of a list object */

TYPE_LIST = 5

kind = ServerKind(root)

/* If not at the absolute root, display the local root variable's name and value. */

if level > 0 then do

	item = "<li>"

	if kind = TYPE_LIST then
		item = item"<b>"

	item = item ServerName(root)

	if kind = TYPE_LIST then
		item = item"</b>"
	else do
		text = ServerReadText(root, "")

		if length(text) = 0 then
			text = "(none)"

		item = item "=" text
	end

	call ServerAppendText html,, item
end

/* If the local root Variable is a list, display it recursively. */

if kind = TYPE_LIST then do
	next = ServerChild(root)

	if next \= 0 then do
		call ServerAppendText html,, "<ul>"

		do until next = 0
			call TourTreeRecursion next, html, level+1
			next = ServerSibling(next)
		end

		call ServerAppendText html,, "</ul>"
	end
end

return

